import Head from 'next/head'
import styles from './styles/Home.module.css'
import React from 'react'
import { utils } from 'ethers'

import { createClient } from 'urql';

const client = createClient({
  url: process.env.NEXT_PUBLIC_APIURL
})

const tokenAuctionQuery = `
  query {
    nftmarketAuctions(
      first: 35
      ) {
      id
      token {
        id
        tokenIPFSPath
        contentURI
      }
      reservePrice
    }
  }
`

async function fetchData() {  
  const auctions = await client.query(tokenAuctionQuery).toPromise()
  const auctionData = await Promise.all(auctions.data.nftmarketAuctions.map(async auction => {
    let meta;
    try {
      meta = await (await fetch(auction.token.contentURI)).json()
      console.log('auction meta: ', meta)
    } catch (err) {}
    if (!meta) return
    if (meta.image.includes('mp4')) {
      auction.type = 'video'
    } else if (meta.image.includes('wav')) {
      auction.type = 'audio'
    } else {
      auction.type = 'image'
    }
    auction.contentURI = meta.image.replace('ipfs://', 'https://ipfs.foundation.app/')
    auction.meta = meta
    return auction
  }))
  return auctionData
}

export default function Index(props) {
  if (props && props.tokens && props.tokens.length) return (
    <div className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-3 xl:grid-cols-4 gap-4 px-10 py-10">
      {
        props.tokens.map(token => {
          return (
            <div className="shadow-lg bg-transparent rounded-2xl overflow-hidden" key={token.id}>
              <div key={token.contentURI}
                className="w-100% h-100%"
              >
                {
                  token.type === 'image' && (
                    <div style={{height: '320px', overflow: 'hidden'}}>
                      <img style={{ minHeight: '320px' }} src={token.contentURI} />
                    </div>
                  )
                }
                {
                  token.type === 'video' && (
                    <div className="relative">
                      <div style={{width: '288px', height: '320px', boxSizing: 'border-box'}} />
                      <div style={{ position: 'absolute', top: 0, left: 0, bottom: 0, right: 0 }}>
                        <video height="auto" controls autoPlay
                        style={{
                          position: 'absolute',
                          width: '100%',
                          height: '100%',
                          display: 'block',
                          objectFit: 'cover'
                        }}>
                          <source src={token.contentURI} />
                        </video>
                      </div>
                    </div>
                  )
                }
                {
                  token.type === 'audio' && (
                    <audio controls>
                      <source src={token.contentURI} type="audio/ogg" />
                      <source src={token.contentURI} type="audio/mpeg" />
                    Your browser does not support the audio element.
                    </audio>
                  )
                }
                <div className="px-2 pt-2 pb-10">
                  <h3
                  style={{ height: 100 }}
                  className="text-2xl p-4 pt-6 font-semibold">{token.meta.name}</h3>
                </div>
              </div>
              <div className="bg-black p-10">
                <p className="text-white">
                  Price
                </p>
                <p className="text-white font-bold text-xl">
                  {utils.formatEther(token.reservePrice)}
                </p>
              </div>
            </div>
          )
        })
      }
    </div>
  )
  return (
    <div className={styles.container}>
      <Head>
        <title>Create Next App</title>
        <meta name="description" content="Generated by create next app" />
        <link rel="icon" href="/favicon.ico" />
      </Head>

      <main className={styles.main}>
        <h1 className={styles.title}>
          Welcome to <a href="https://nextjs.org">Next.js!</a>
        </h1>
      </main>
    </div>
  )
}

export async function getServerSideProps() {
  const data = await fetchData()
  return {
    props: {
      tokens: data
    }
  }
}
